=============
eldl
=============

|eldl|_ is an electrochemical dynamics library written in Python.

.. start

Install `eldl`
================

`eldl` requires: Python_ 3.10+ or PyPy3.

1. Run the following command in your command line:

.. code-block::

    pip install eldl

2. Check that you've installed the correct version:

.. code-block:: python

    >>> from eldl.__about__ import __version__
    >>> print(__version__)
    0.0.1a1

You can also install the in-development version with:

.. code-block::

    pip install git+ssh://https://github.com/ugognw/eldl.git@development

Documentation
=============

View the latest version of the documentation on `Read the Docs`_

.. _Python: https://www.python.org
.. _Read the Docs: https://eldl.readthedocs.io/en/latest
.. |eldl| replace:: `eldl`
.. _eldl: https://github.com/ugognw/eldl
